bcfa(..., ov.cp = "srs", lv.cp = "srs", dp = dpriors(), n.chains = 3, burnin, sample, adapt, jagfile = FALSE, jagextra = list(), inits = "prior", convergence = "manual", jagcontrol = list())lavaan."srs" or
"fa". Option "srs" is more flexible and better from a
theoretical standpoint, but it is also slower.ov.cp argument.dpriors().
See the dpriors() help file for more information.TRUE, the JAGS model will be written to file
(in the lavExport directory). Can also supply a character
string, which serves as the name of the directory to which files will be written.syntax and
monitor. The syntax object is a text string containing extra
code to insert in the JAGS model syntax, and the monitor object
is a character vector containing extra JAGS parameters to sample."simple", "Mplus", "prior" (default), and
"jags". In the first two
cases, parameter values are set as though they will be estimated via
ML (see lavaan). The starting parameter value for
each chain is then perturbed from the original values through the
addition of uniform noise. If "prior" is used, the starting
parameter values are obtained based on the prior distributions
(while also trying to ensure that the starting values will not crash
the model estimation). If "jags", no starting values are
specified and JAGS will choose values on its own.
If start is a fitted
object of class lavaan, the estimated values of
the corresponding parameters will be extracted, then perturbed in
the manner described above. If it is a model list,
for example the output of the paramaterEstimates() function,
the values of the est or start or ustart column
(whichever is found first) will be extracted."auto", parameters will be
sampled until convergence is achieved (via autorun.jags). In
this case, the arguments burnin and sample are passed to
autorun.jags as startburnin and startsample,
respectively. Otherwise, parameters
are sampled as specified by the user (or by the run.jags defaults).run.jags (or autorun.jags). See the manpage of those functions for an
overview of the additional parameters that can be set. No other
model estimation functions are currently available.lavaan, for which several methods
are available, including a summary method.
bcfa function is a wrapper for the more general
blavaan function, using the following default
lavaan arguments:
int.ov.free = TRUE, int.lv.free = FALSE,
auto.fix.first = TRUE (unless std.lv = TRUE),
auto.fix.single = TRUE, auto.var = TRUE,
auto.cov.lv.x = TRUE,
auto.th = TRUE, auto.delta = TRUE,
and auto.cov.y = TRUE.
Edgar C. Merkle & Yves Rosseel (2015). blavaan: Bayesian Structural Equation Models via Parameter Expansion.
blavaan
## Not run:
# # The Holzinger and Swineford (1939) example
# HS.model <- ' visual =~ x1 + x2 + x3
# textual =~ x4 + x5 + x6
# speed =~ x7 + x8 + x9 '
#
# fit <- bcfa(HS.model, data=HolzingerSwineford1939,
# jagcontrol=list(method="rjparallel"))
# summary(fit)
# ## End(Not run)
Run the code above in your browser using DataLab